import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-amazon-chime-resources",
    "0.0.107",
    __name__[0:-6],
    "cdk-amazon-chime-resources@0.0.107.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
